<?php

// get CM2 options
if ( ! function_exists( 'terraclassifieds_get_option_base_functions' ) ) {
	function terraclassifieds_get_option_base_functions( $key = '', $default = false ) {
		if ( function_exists( 'cmb2_get_option' ) ) {
			// Use cmb2_get_option as it passes through some key filters.
			return cmb2_get_option( 'terraclassifieds_settings', $key, $default );
		}
		// Fallback to get_option if CMB2 is not loaded yet.
		$opts = get_option( 'terraclassifieds_settings', $default );
		$val = $default;
		if ( 'all' == $key ) {
			$val = $opts;
		} elseif ( is_array( $opts ) && array_key_exists( $key, $opts ) && false !== $opts[ $key ] ) {
			$val = $opts[ $key ];
		}
		return $val;
	}
}

// custom images size
$tcf_image_archive_size_width = terraclassifieds_get_option_base_functions( '_tc_image_archive_width', '170' );
$tcf_image_archive_size_height = terraclassifieds_get_option_base_functions( '_tc_image_archive_height', '145' );
$tcf_image_single_size_width = terraclassifieds_get_option_base_functions( '_tc_image_single_width', '980' );
$tcf_image_single_size_height = terraclassifieds_get_option_base_functions( '_tc_image_single_height', '735' );
add_image_size( 'tcf-archive', $tcf_image_archive_size_width, $tcf_image_archive_size_height );
add_image_size( 'tcf-single', $tcf_image_single_size_width, $tcf_image_single_size_height );

// custom excerpt function
if ( ! function_exists( 'terraclassifieds_excerpt' ) ) {
	function terraclassifieds_excerpt( $len = 55, $trim = '&hellip;', $readmore = false, $ignore = false ) {
		global $post;

		if ( strpos( $post->post_content, '<!--more-->' ) && $len > 0 && $ignore == false ) { //if more quicktag in post
			if ( $readmore === true ) {
				echo '<!-- with readmore -->';
				the_content(); //with readmore
			} else {
				echo '<!-- no readmore -->';
				the_content( '' ); //no readmore
			}
		} elseif ( $len == 'full' ) {
			echo '<!-- full content -->';
			the_content( '' );
		} elseif ( $len == 0 ) {
			echo '<!-- excerpt 0 -->';
		} else { //prepare excerpt depends on limit
			echo '<!-- excerpt ' . esc_attr($len) . ' -->';
			$limit     = $len + 1;
			$excerpt   = explode( ' ', strip_tags( get_the_content() ), $limit );
			$num_words = count( $excerpt );
			$trim      = ' ' . $trim;

			if ( $num_words >= $len ) {
				$last_item = array_pop( $excerpt );
			} else {
				$trim = '';
			}

			$excerpt = implode( ' ', $excerpt );

			$excerpt = rtrim( $excerpt, ',' );
			$excerpt = rtrim( $excerpt, '.' );

			$excerpt .= $trim;

			if ( $readmore === true ) { //with readmore
				$excerpt .= pe_read_more_link();
			}
			echo apply_filters( 'the_content', $excerpt );
		}
	}
}

// Equipment Category Dropdown
class Walker_SlugValueCategoryDropdown extends Walker_CategoryDropdown {
        function start_el(&$output, $category, $depth = 0, $args = array(), $id = 0) {
        $pad = str_repeat('-', $depth * 1);

        $cat_name = apply_filters('list_cats', $category->name, $category);
        $output .= "\t<option class=\"level-$depth\" value=\"".$category->slug."\"";
        if ( $category->slug == $args['selected'] )
            $output .= ' selected="selected"';
        $output .= '>';
        $output .= $pad.' '.$cat_name;
        if ( $args['show_count'] )
            $output .= '&nbsp;&nbsp;('. $category->count .')';
        $output .= "</option>\n";
    }
}

// Equipment Location Dropdown
class Walker_SlugValueLocationDropdown extends Walker_CategoryDropdown {
        function start_el(&$output, $category, $depth = 0, $args = array(), $id = 0) {
        $pad = str_repeat('-', $depth * 1);

        $cat_name = apply_filters('list_cats', $category->name, $category);
        $output .= "\t<option class=\"level-$depth\" value=\"".$category->slug."\"";
        if ( $category->slug == $args['selected'] )
            $output .= ' selected="selected"';
        $output .= '>';
        $output .= $pad.' '.$cat_name;
        if ( $args['show_count'] )
            $output .= '&nbsp;&nbsp;('. $category->count .')';
        $output .= "</option>\n";
    }
}
		
//prepare search form
if ( ! function_exists( 'terraclassifiedsSearchForm' ) ) {
	function terraclassifiedsSearchForm( $instance ) {
		
		$category_filter = ( ! empty( $instance['category_filter'] ) && $instance['category_filter'] == 1 ) ? true : false;
		$only_first_level = ( ! empty( $instance['only_first_level'] ) && $instance['only_first_level'] == 1 ) ? true : false;
		if($only_first_level){
			$depth = 1;
		} else {
			$depth = 0;
		}
		
		$location = ( ! empty( $instance['location'] ) && $instance['location'] == 1 ) ? true : false;
		
		$search_word_get = '';		
		if (isset($_GET['s'])) {
		  $search_word_get = $_GET['s'];
		}
		
		$location_option = ( ! empty( $instance['location_option'] ) && $instance['location_option'] == 1 ) ? true : false;
		$location_list_hierarchical = ( ! empty( $instance['location_list_hierarchical'] ) && $instance['location_list_hierarchical'] == 1 ) ? true : false;
		
		$type_show = terraclassifieds_get_option_base_functions( '_tc_use_types', '0' );
		$type = ( ! empty( $instance['type'] ) && $instance['type'] == 1 ) ? true : false;
		
		$more_enabled = '';
		if( $type && $type_show ) {
			$more_enabled = 'terraclassifieds-more-fields';
		}
		
		$search_size1 = esc_attr( $instance['search_large_size'] );
		$search_size2 = esc_attr( $instance['search_desktop_size'] );
		$search_size3 = esc_attr( $instance['search_tablet_size'] );
		$search_size4 = esc_attr( $instance['search_phone_size'] );
		$location_size1 = esc_attr( $instance['location_large_size'] );
		$location_size2 = esc_attr( $instance['location_desktop_size'] );
		$location_size3 = esc_attr( $instance['location_tablet_size'] );
		$location_size4 = esc_attr( $instance['location_phone_size'] );
		$category_size1 = esc_attr( $instance['category_large_size'] );
		$category_size2 = esc_attr( $instance['category_desktop_size'] );
		$category_size3 = esc_attr( $instance['category_tablet_size'] );
		$category_size4 = esc_attr( $instance['category_phone_size'] );
		
		$form = '<form action="' . esc_url( home_url( '/' ) ) . '" id="terraclassifieds-search-form" method="get" class="terraclassifieds-search-form ' . $more_enabled . '">
			<div class="terraclassifieds-search-fields">
			<div class="row">
			<div class="terraclassifieds-search-word col-lg-'.$search_size1.' col-md-'.$search_size2.' col-sm-'.$search_size3.' col-xs-'.$search_size4.'">
			<label class="screen-reader-text" for="terraclassifieds-product-search-field">' . __( "Search for:", "terraclassifieds" ) . '</label>
			<input type="search" id="terraclassifieds-product-search-field" class="terraclassifieds-product-search-field" placeholder="' . esc_attr__( "Search products&hellip;", "terraclassifieds" ) . '" value="'.$search_word_get.'" name="s" />
			</div>';

		if( $category_filter ) {

				$category_get = '';		
				if (isset($_GET['ad_category'])) {
				  $category_get = $_GET['ad_category'];
				}
				
	            $dropdown_args = array(
	                'taxonomy'      => 'ad_category',
	                'id'                 => 'ad_category',
	                'name'                 => 'ad_category',
	                'depth'              => $depth,
	                'show_option_none'  => esc_html__( 'All categories', 'terraclassifieds' ),
	                'option_none_value' => 0,
	                'show_count'        => 1,
	                'orderby'       => 'name',
	                'hierarchical'      => true,
	                'echo'          => 0,
	                'walker'            => new Walker_SlugValueCategoryDropdown,
	                'value_field' => 'slug',
	                'selected' => $category_get,
				);
					
				$form .= '<div class="terraclassifieds-search-category col-lg-'.$category_size1.' col-md-'.$category_size2.' col-sm-'.$category_size3.' col-xs-'.$category_size4.'">'.wp_dropdown_categories( $dropdown_args ).'</div>';

		}
		
		if( $location ) {
			
			$form .= '<div class="terraclassifieds-search-location col-lg-'.$location_size1.' col-md-'.$location_size2.' col-sm-'.$location_size3.' col-xs-'.$location_size4.'">';
			
				if($location_option) {
					$location_get = '';		
					if (isset($_GET['ad_location'])) {
					  $location_get = $_GET['ad_location'];
					}
					$form .= wp_nonce_field( 'terraclassifiedsLocationsAjax', 'location_nonce' );
					$form .=  '<input type="text" id="terraclassifieds-product-search-location-field" class="terraclassifieds-product-search-field location-tax-input ui-autocomplete-input" data-taxonomy="ad_location" placeholder="' . esc_attr__( "Enter location&hellip;", "terraclassifieds" ) . '" value="' . $location_get . '" name="ad_location" /><span class="terraclassifieds-location-more-characters">' . esc_attr__( "Please enter minimum 3 characters.", "terraclassifieds" ) . '</span><span class="terraclassifieds-location-no-location">' . esc_attr__( "Can't find the location.", "terraclassifieds" ) . '</span>';
					
				} else {
					
					$location_get = '';
					if (isset($_GET['ad_location'])) {
					  $location_get = $_GET['ad_location'];
					}
					
		            $location_dropdown_args = array(
		                'taxonomy'      => 'ad_location',
		                'id'                 => 'ad_location',
		                'name'                 => 'ad_location',
		                'show_option_none'  => esc_html__( 'All locations', 'terraclassifieds' ),
		                'option_none_value' => 0,
		                'show_count'        => 1,
		                'orderby'       => 'name',
		                'hierarchical'      => $location_list_hierarchical,
		                'echo'          => 0,
		                'walker'            => new Walker_SlugValueLocationDropdown,
		                'value_field' => 'slug',
		                'selected' => $location_get,
						);
						
					$form .= wp_dropdown_categories( $location_dropdown_args );
					
				}
			$form .= '</div>';
		}
		$form .= '</div>';
		
		if( $type && $type_show ) {
			
			$form .= '</div>';
			
			$form .= '<div class="terraclassifieds-search-more-wrapper clearfix">';
			
				$form .= '<span class="terraclassifieds-more">' . esc_attr_x( "More", "search more", "terraclassifieds" ) . '</span>';
				
				$form .= '<div class="terraclassifieds-search-type">';
						
						$type_get = '';
						if (isset($_GET['ad_type'])) {
						  $type_get = $_GET['ad_type'];
						}

						$array_excluded_terms = array();
						$terraclassifieds_types = get_terms( 'ad_type', array(
						    'hide_empty' => true,
						) );
						foreach($terraclassifieds_types as $terraclassifieds_type) {
							$type_use_in_search = get_term_meta( $terraclassifieds_type->term_id, '_tc_type_use_in_search', true);
							if($type_use_in_search != 'yes'){
								array_push($array_excluded_terms, $terraclassifieds_type->term_id);
							}
						}
						
			            $type_dropdown_args = array(
			                'taxonomy'      => 'ad_type',
			                'id'                 => 'ad_type',
			                'name'                 => 'ad_type',
			                'show_option_none'  => false,
			                'option_none_value' => 0,
			                'show_count'        => 0,
			                'orderby'       => 'name',
			                'hierarchical'      => true,
			                'echo'          => 0,
			                'value_field' => 'slug',
			                'selected' => $type_get,
			                'exclude'            => $array_excluded_terms,
							);
							
						$form .= wp_dropdown_categories( $type_dropdown_args );
	
				$form .= '</div>';
			
			$form .= '</div>';
		}
		
		if( !($type && $type_show) ) {
			$form .= '</div>';
		}
		
		
		if( $type && $type_show ) {
			$form .= '<div class="terraclassifieds-clear-area">
				<div class="terraclassifieds-clear-button">';
					$form .= '<i class="fa fa-close"></i>' . esc_attr_x( "Clear", "search more", "terraclassifieds" );
				$form .= '</div>
			</div>';
		}

		$form .= '<button type="submit" class="terraclassifieds-btn" value="' . esc_attr_x( "Search", "submit button", "terraclassifieds" ) . '">' . esc_html_x( "Search", "submit button", "terraclassifieds" ) . '</button>';

		$form .= '<input type="hidden" name="post_type" value="classified" />
		</form>';
		return $form;
	}
}

// custom search form on search results page and category view
if ( ! function_exists( 'terraclassifiedsSearchFormInit' ) ) {
	add_filter('get_search_form', 'terraclassifiedsSearchFormInit');
	function terraclassifiedsSearchFormInit($form = false) {
		//if ( isset($_GET['post_type']) && $_GET['post_type'] == 'classified' ) {
		$search_form_show = terraclassifieds_get_option_base_functions( '_tc_archive_search', '1' );
		$category_show = terraclassifieds_get_option_base_functions( '_tc_archive_search_category_show', '1' );
		$category_only_first_level = terraclassifieds_get_option_base_functions( '_tc_archive_search_category_only_first_level', '0' );
		$location_show = terraclassifieds_get_option_base_functions( '_tc_archive_search_location_show', '1' );
		$type_show = terraclassifieds_get_option_base_functions( '_tc_use_types', '0' );
		$type_filter = terraclassifieds_get_option_base_functions( '_tc_archive_search_use_type_filter', '0' );
		$location_kind = terraclassifieds_get_option_base_functions( '_tc_archive_search_location_kind', '0' );
		$location_list_hierarchical = terraclassifieds_get_option_base_functions( '_tc_archive_search_location_hierarchical', '1' );
		$search_size1 = terraclassifieds_get_option_base_functions( '_tc_search_size1', '4' );
		$search_size2 = terraclassifieds_get_option_base_functions( '_tc_search_size2', '4' );
		$search_size3 = terraclassifieds_get_option_base_functions( '_tc_search_size3', '12' );
		$search_size4 = terraclassifieds_get_option_base_functions( '_tc_search_size4', '12' );
		$location_size1 = terraclassifieds_get_option_base_functions( '_tc_location_size1', '4' );
		$location_size2 = terraclassifieds_get_option_base_functions( '_tc_location_size2', '4' );
		$location_size3 = terraclassifieds_get_option_base_functions( '_tc_location_size3', '12' );
		$location_size4 = terraclassifieds_get_option_base_functions( '_tc_location_size4', '12' );
		$category_size1 = terraclassifieds_get_option_base_functions( '_tc_category_size1', '4' );
		$category_size2 = terraclassifieds_get_option_base_functions( '_tc_category_size2', '4' );
		$category_size3 = terraclassifieds_get_option_base_functions( '_tc_category_size3', '12' );
		$category_size4 = terraclassifieds_get_option_base_functions( '_tc_category_size4', '12' );
		$type_search = 0;
		if($type_show && $type_filter){
			$type_search = 1;
		}
		$instance = array(
			'category_filter' => $category_show,
			'only_first_level' => $category_only_first_level,
			'location' => $location_show,
			'location_option' => $location_kind,
			'location_list_hierarchical' => $location_list_hierarchical,
			'type' => $type_search,
			'search_large_size'    => $search_size1,
			'search_desktop_size'    => $search_size2,
			'search_tablet_size'    => $search_size3,
			'search_phone_size'    => $search_size4,
			'location_large_size'    => $location_size1,
			'location_desktop_size'    => $location_size2,
			'location_tablet_size'    => $location_size3,
			'location_phone_size'    => $location_size4,
			'category_large_size'    => $category_size1,
			'category_desktop_size'    => $category_size2,
			'category_tablet_size'    => $category_size3,
			'category_phone_size'    => $category_size4,
		);
		if($search_form_show){
			return terraclassifiedsSearchForm( $instance );
		} else {
			return false;
		}
		//}
	}
}

// add custom post type "classified" to search in ad search results view
if ( ! function_exists( 'terraclassifiedsSearch' ) ) {
	add_filter( 'pre_get_posts', 'terraclassifiedsSearch', 9999 );
	function terraclassifiedsSearch( $query ) {
		if (isset($_GET['post_type']) && $_GET['post_type'] == 'classified') {
			if ( $query->is_search ) {
				$query->set( 'post_type', array( 'classified' ) );
			}
			return $query;
		}
	}
}

// add Custom Post Type "classified" to author archive view
if ( ! function_exists( 'terraclassifiedsAuthorArchive' ) ) {
	add_action('pre_get_posts', 'terraclassifiedsAuthorArchive');
	function terraclassifiedsAuthorArchive($query) {
		if (is_author()) {
			$query->set( 'post_type', array('classified', 'post') );
		}
		remove_action( 'pre_get_posts', 'terraclassifiedsAuthorArchive' );
	}
}

if( !function_exists('terraclassifieds_date_ago') ) {
	function terraclassifieds_date_ago($time) {
		$period = array(
			__("second", 'terraclassifieds'),
			__("minute", 'terraclassifieds'),
			__("hour", 'terraclassifieds'),
			__("day", 'terraclassifieds'),
			__("week", 'terraclassifieds'),
			__("month", 'terraclassifieds'),
			__("year", 'terraclassifieds'),
			__("decade", 'terraclassifieds')
		);
		$periods = array(
			__("seconds", 'terraclassifieds'),
			__("minutes", 'terraclassifieds'),
			__("hours", 'terraclassifieds'),
			__("days", 'terraclassifieds'),
			__("weeks", 'terraclassifieds'),
			__("months", 'terraclassifieds'),
			__("years", 'terraclassifieds'),
			__("decades", 'terraclassifieds')
		);
		$lengths = array("60","60","24","7","4.35","12","10");
		$ago = __('ago', 'terraclassifieds');
	
		$now = time();
		$difference     = $now - $time;
	
		for($j = 0; $difference >= $lengths[$j] && $j < count($lengths)-1; $j++) {
			$difference /= $lengths[$j];
		}
	
		$difference = round($difference);
		$period = ( $difference == 1 ) ? $period[$j] : $periods[$j];
	
		return "$difference $period $ago";
	}
}

if( !function_exists('terraclassifieds_date_from_now') ) {
	function terraclassifieds_date_from_now($time) {
		$period = array(
			__("second", 'terraclassifieds'),
			__("minute", 'terraclassifieds'),
			__("hour", 'terraclassifieds'),
			__("day", 'terraclassifieds'),
			__("week", 'terraclassifieds'),
			__("month", 'terraclassifieds'),
			__("year", 'terraclassifieds'),
			__("decade", 'terraclassifieds')
		);
		$periods = array(
			__("seconds", 'terraclassifieds'),
			__("minutes", 'terraclassifieds'),
			__("hours", 'terraclassifieds'),
			__("days", 'terraclassifieds'),
			__("weeks", 'terraclassifieds'),
			__("months", 'terraclassifieds'),
			__("years", 'terraclassifieds'),
			__("decades", 'terraclassifieds')
		);
		$lengths = array("60","60","24","7","4.35","12","10");
		$from_now = __('from now', 'terraclassifieds');
	
		$now = time();
		$difference     = $time - $now;
	
		for($j = 0; $difference >= $lengths[$j] && $j < count($lengths)-1; $j++) {
			$difference /= $lengths[$j];
		}
	
		$difference = round($difference);
		$period = ( $difference == 1 ) ? $period[$j] : $periods[$j];
	
		return "$difference $period $from_now";
	}
}

if ( ! function_exists( 'terraclassifieds_pagination' ) ) {
	/**
	 * Modify default pagination
	 *
	 * @param integer $pages Number of pages in listing
	 */
	function terraclassifieds_pagination( $pages = false ) {
		global $paged;

		if ( empty( $paged ) ) {
			$paged = 1;
		}

		$prev      = $paged - 1;
		$next      = $paged + 1;
		$range     = 1; // only change it to show more links
		$showitems = 3;

		if ( $pages === false ) {
			global $wp_query;
			$pages = $wp_query->max_num_pages;
			if ( ! $pages ) {
				$pages = 1;
			}
		}

		if ( $pages != 1 ) {

			echo '<nav class="terraclassifieds-pagination"><ul class="terraclassifieds-pagination-list">';
			echo ( $paged > 1 ) ? '<span class="prev"><a href="' . esc_url( get_pagenum_link( $prev ) ) . '">' . esc_html__( 'Prev', 'terraclassifieds' ) . '</a></span>' : '';
			
			for ( $i = 1; $i <= $pages; $i ++ ) {
				echo ( $paged == $i ) ? '<span class="active"><span>' . esc_attr($i) . '</span></span> ' : '<span><a href="' . esc_url( get_pagenum_link( $i ) ) . '">' . esc_attr($i) . '</a></span>';
			}
			echo ( $paged < $pages ) ? '<span class="next"><a href=' . esc_url( get_pagenum_link( $next ) ) . '>' . esc_html__( 'Next', 'terraclassifieds' ) . '</a></span>' : '';
			echo '</ul></nav>';
		}
	}
}

///notices
if( !function_exists('terraclassifieds_notice_send_success') ) {
	function terraclassifieds_notice_send_success() {
	    terraclassifieds_display_notice("success", __('Message was sent successfully.', 'terraclassifieds'));
	}
}
if( !function_exists('terraclassifieds_notice_send_error') ) {
	function terraclassifieds_notice_send_error() {
	    terraclassifieds_display_notice("error", __('Message could not be sent.', 'terraclassifieds'));
	}
}
if ( ! function_exists( 'terraclassifieds_display_notice' ) ) {
	function terraclassifieds_display_notice( $status, $message ) {
		echo '<div class="terraclassifieds-notice ' . sanitize_html_class($status) . '">' . $message . '</div>';
	}
}

if ( ! function_exists( 'terraclassifieds_save_ad' ) ) {
	function terraclassifieds_save_ad() {
	
		if( 'POST' == $_SERVER['REQUEST_METHOD'] && !empty( $_POST['tc_form_action'] ) && $_POST['tc_form_action'] == 'add_item' ) {	
	
			$taxonomy = array(
				'ad_category' => array(
					$_POST['cat']
				)
			);
	
			// Add the content of the form to $post as an array
			$post = array(
				'post_title'	=> sanitize_text_field($_POST['title']),
				'post_content'	=> sanitize_text_field($_POST['description']),
				'post_status'	=> 'publish',
				'post_author'   => get_current_user_id(),
				'post_type'	=> 'classified',
				'tax_input'    => $taxonomy,
			);
	
			$insert = wp_insert_post($post);
			if( is_wp_error( $insert ) ){
				echo $insert->get_error_message();
			} else {
				wp_redirect( home_url() );
			}
	
		}
	}
	add_action( 'wp_loaded', 'terraclassifieds_save_ad' );
}


// echo only first image
if ( ! function_exists( 'cmb2_output_file_list_first_image' ) ) {
	function cmb2_output_file_list_first_image( $file_list_meta_key, $img_size = 'medium' ) {
		$tcf_image_archive_size_height = terraclassifieds_get_option_base_functions( '_tc_image_archive_height', '145' );
		// Get the list of files
		$files = get_post_meta( get_the_ID(), $file_list_meta_key, 1 );
		echo '<div class="terraclassifieds-gallery" style="min-height: '.esc_attr($tcf_image_archive_size_height).'px;">';
		$files_counter = 0;
		// Loop through them and output an image
		foreach ( (array) $files as $attachment_id => $attachment_url ) {
			if($files_counter < 1){
				echo '<div class="terraclassifieds-gallery-element">';
					echo wp_get_attachment_image( $attachment_id, $img_size );
				echo '</div>';
			}
			$files_counter++;
		}
		echo '</div>';
	}
}

// update ad status - to archive
if ( ! function_exists( 'terraclassifieds_to_archive' ) ) {
	function terraclassifieds_to_archive($pid){
		if (isset($_POST["submit-archive-$pid"])){
			wp_update_post(array('ID' => $pid, 'post_status'   =>  'archived')); ?>
			<script>
				( function($){
					$(document).ready(function(){
						$('.post-<?php echo esc_attr($pid); ?> .terraclassifieds-status span').closest('.type-classified').removeClass('status-publish');
						$('.post-<?php echo esc_attr($pid); ?> .terraclassifieds-status span').closest('.type-classified').addClass('status-archived');
						$('.post-<?php echo esc_attr($pid); ?> .terraclassifieds-status span').html( "<?php echo __( 'Archived', 'terraclassifieds' ); ?>" );
						$('.post-<?php echo esc_attr($pid); ?> .terraclassifieds-status i').replaceWith('<i class="fa fa-dot-circle-o" aria-hidden="true"></i>');
					});
				})( jQuery );
			</script>
		<?php }
	}
}

// update ad status - to publish
if ( ! function_exists( 'terraclassifieds_to_publish' ) ) {
	function terraclassifieds_to_publish($pid){
		if (isset($_POST["submit-publish-$pid"])){
			$expire_time = intval(terraclassifieds_get_option( '_tc_advert_expire_time', 30 ));
		    $new_date = new DateTime( 'now' );
		    $new_date->modify( "+".$expire_time." day" );
			$expire_time_field =  $new_date->format('U');
			wp_update_post(array('ID' => $pid, 'post_status'   =>  'publish'));
			update_post_meta( $pid, '_tc_expire_date', $expire_time_field );
			update_post_meta( get_the_ID(), '_tc_expire_soon_notification_done', false );
			?>
			<script>
				( function($){
					$(document).ready(function(){
						$('.post-<?php echo esc_attr($pid); ?> .terraclassifieds-status span').closest('.type-classified').removeClass('status-archived');
						$('.post-<?php echo esc_attr($pid); ?> .terraclassifieds-status span').closest('.type-classified').addClass('status-publish');
						$('.post-<?php echo esc_attr($pid); ?> .terraclassifieds-status span').html( "<?php echo __( 'Published', 'terraclassifieds' ); ?>" );
						$('.post-<?php echo esc_attr($pid); ?> .terraclassifieds-status i').replaceWith('<i class="fa fa-check-square" aria-hidden="true"></i>');
					});
				})( jQuery );
			</script>
		<?php }
	}
}

// update ad status - remove
if ( ! function_exists( 'terraclassifieds_remove' ) ) {
	function terraclassifieds_remove($pid){
		if (isset($_POST["submit-remove-$pid"])){
			wp_delete_post($pid); ?>
			?>
			<script>
				( function($){
					$(document).ready(function(){
						$('.post-<?php echo esc_attr($pid); ?>').remove();
					});
				})( jQuery );
			</script>
		<?php }
	}
}

// add class if admin is logged in
if ( ! function_exists( 'terraclassifieds_body_class_admin' ) ) {
	add_filter( 'body_class', 'terraclassifieds_body_class_admin' );
	function terraclassifieds_body_class_admin( $classes ) {
		$admin_class = '';
		if(current_user_can('administrator')){
			$admin_class = 'admin-on-board';
		}
		return array_merge( $classes, array( $admin_class ) );
	}
}

// breadcrumbs
if ( ! function_exists( 'terraclassifieds_breadcrumbs' ) ) {
	function terraclassifieds_breadcrumbs( $args = array() ) {
		global $post;
		$html = '<div class="terraclassifieds-breadcrumb">';
		$html .= '<span class="terraclassifieds-you-are-here">' . esc_html__( 'You are here', 'terraclassifieds' ) . ': </span>';
		$html .= '<span class="item-home"><a class="bread-link bread-home" href="' . get_home_url() . '"><span>' . esc_html__( 'Home', 'terraclassifieds' ) . '</span></a></span>';
		$html .= '<span class="terraclassifieds-breadcrumb-separator"> <i class="fa fa-angle-right" aria-hidden="true"></i> </span>';

		if ( is_singular( 'classified' ) ) {
			$last_category = wp_get_post_terms(  $post->ID , 'ad_category');
			if(!empty($last_category)){
				$last_category_id = $last_category[0]->term_id;
				$html .= get_term_parents_list($last_category_id , 'ad_category',
			        array(
			            'separator' => '<span class="terraclassifieds-breadcrumb-separator"> <i class="fa fa-angle-right" aria-hidden="true"></i> </span>',
			        )
				);
			}
			$html .= '<span> ' . esc_attr( get_the_title() ) . '</span>';
		} if ( is_tax( 'ad_category' ) ) {
			$this_category_id = get_queried_object()->term_id;
			$html .= get_term_parents_list($this_category_id , 'ad_category',
		        array(
		            'separator' => '<span class="terraclassifieds-breadcrumb-separator"> <i class="fa fa-angle-right" aria-hidden="true"></i> </span>',
		        )
			);
		}
		$html .= '</div>';
		echo wp_kses_post( $html );
	}
}

// login - stop redirect to wp-login.php after entering a wrong password
if ( ! function_exists( 'terraclassifieds_custom_login_failed' ) ) {
	add_action( 'wp_login_failed', 'terraclassifieds_custom_login_failed' );
	function terraclassifieds_custom_login_failed( $username ){
	    $referrer = wp_get_referer();
	    $page_login = get_page_by_path("login");
	    if ($page_login) {
	        $page_id =  $page_login->ID;
	    }
	    if ( $referrer && ! strstr($referrer, 'wp-login') && ! strstr($referrer,'wp-admin') && (strstr($referrer,'login') || strstr($referrer,"?page_id=" . $page_id)) )
	    {
	        wp_redirect( add_query_arg('login', 'failed', $referrer) );
	        exit;
	    }
	}
}

// login - stop redirect to wp-login.php when login or password is empty
if ( ! function_exists( 'terraclassifieds_custom_authenticate_username_password' ) ) {
	add_filter( 'authenticate', 'terraclassifieds_custom_authenticate_username_password', 30, 3);
	function terraclassifieds_custom_authenticate_username_password( $user, $username, $password ){
	    if ( is_a($user, 'WP_User') ) { return $user; }
	}
}

// override posts per page for category
if ( ! function_exists( 'terraclassifieds_posts_per_page' ) ) {
	add_action( 'pre_get_posts',  'terraclassifieds_posts_per_page'  );
	function terraclassifieds_posts_per_page( $query ) {
		$items_per_page = terraclassifieds_get_option( '_tc_category_view_items_per_page', '4' );
		//echo '<pre>';
		//print_r($query);
		//echo '</pre>';
		if(!is_page() && !is_tax('ad_location')){
			if ( ! is_admin() && ($query->is_archive() && !empty($query->query['ad_category']) || $query->is_search() && $query->query['post_type'] == "classified") ){
			  $query->set( 'posts_per_page', $items_per_page );
			}
		}
	}
}

// add subcategories class to BODY for add advert view
if ( ! function_exists( 'terraclassifieds_add_advert_body_class' ) ) {
	add_filter( 'body_class','terraclassifieds_add_advert_body_class' );
	function terraclassifieds_add_advert_body_class( $classes ) {
		$subcategories_columns_number = terraclassifieds_get_option( '_tc_add_advert_subcategories_columns', 4 );
		if(is_page('add-advert')){
			$classes[] = 'subcategories-'.$subcategories_columns_number;
		} else {
			$classes[] = '';
		}
	    return $classes;
	}
}


// save title and description into _tc_post_title and _tc_post_content fields when create ad in the backend
if ( ! function_exists( 'terraclassifieds_save_fake_title_desc' ) ) {
	function terraclassifieds_save_fake_title_desc( $post_id, $post, $update ) {
	
	    $post_type = get_post_type($post_id);
	
	    // If this isn't a 'classified' post, don't update it.
	    if ( "classified" != $post_type && is_admin() ) return;
	
	    // - Update the post's metadata.
	    if ( isset( $_POST['post_title'] ) ) {
	    	update_post_meta( $post_id, '_tc_post_title', $_POST['post_title'] );
	    }
	    if ( isset( $_POST['content'] ) ) {
	    	update_post_meta( $post_id, '_tc_post_content', $_POST['content'] );
	    }
		
	}
	add_action( 'save_post', 'terraclassifieds_save_fake_title_desc', 12, 3 );
}

// ajax search for location search as an inputbox
add_action('wp_ajax_nopriv_terraclassifiedsLocationsAjax', 'terraclassifiedsLocationsAjax');
add_action('wp_ajax_terraclassifiedsLocationsAjax', 'terraclassifiedsLocationsAjax');

if ( ! function_exists( 'terraclassifiedsLocationsAjax' ) ) {
	function terraclassifiedsLocationsAjax() {
	
		 if ( check_ajax_referer( 'terraclassifiedsLocationsAjax', 'nonce', false ) == false ) {
		 	wp_send_json_error();
		 }
	
	
		if( !empty($_POST['name']) && !empty($_POST['taxonomy'])  ) {
	
			$terms = get_terms( array(
				'taxonomy'     => $_POST['taxonomy'],
				'name__like'   => $_POST['name'],
				'hide_empty'   => true,
				'hierarchical' => false
			) );
	
			$results = [];
			foreach ($terms as $term) {
				$item = new stdClass();
				$item->value = $term->name;
				$item->id = $term->term_id;
				$results[] = $item;
			}
	
			wp_send_json_success( $results );
	
		}
	
	}
}

// meta description for single ad and ad category
if ( ! function_exists( 'terraclassifiedsMetaDescription' ) ) {
	function terraclassifiedsMetaDescription() {
	    global $post;
		$meta_description_limit = terraclassifieds_get_option_base_functions( '_tc_meta_description_text_limit', '158' );
	    if ( is_singular('classified') ) {
	        $des_post = strip_tags( $post->post_content );
	        $des_post = strip_shortcodes( $post->post_content );
	        $des_post = str_replace( array("\n", "\r", "\t"), ' ', $des_post );
	        $des_post = mb_substr( $des_post, 0, $meta_description_limit, 'utf8' );
	        echo '<meta name="description" content="' . $des_post . '" />' . "\n";
	    }
	    if ( is_tax('ad_category') ) {
	        $category_description = strip_tags( category_description() );
	        $desc_cat = strip_shortcodes( $category_description );
	        $desc_cat = str_replace( array("\n", "\r", "\t"), ' ', $desc_cat );
	        $desc_cat = mb_substr( $desc_cat, 0, $meta_description_limit, 'utf8' );
	         echo '<meta name="description" content="' . $desc_cat . '" />' . "\n";
	    }
	}
	add_action( 'wp_head', 'terraclassifiedsMetaDescription');
}